@@ -1,19 +1,22 @@
 import asyncio
 import datetime
-from copy import copy
 
-from nonebot.plugin import PluginMetadata, on_command
+from nonebot import get_bot, get_driver, require
+from nonebot.adapters.onebot.v11 import (
+    Bot,
+    GroupMessageEvent,
+    Message,
+    MessageSegment,
+    NetworkError,
+)
 from nonebot.log import logger
-from nonebot.adapters.onebot.v11 import GroupMessageEvent, Message, Bot, MessageSegment, \
-    NetworkError
 from nonebot.matcher import Matcher
 from nonebot.params import CommandArg
+from nonebot.plugin import PluginMetadata, on_command
 from nonebot.typing import Union
-from nonebot import require, get_bot, get_driver
 from pydantic import BaseModel
 
 from .data_source import LoLMatch, create_image
-from .model import disconnect_database
 from .template import match_brief_builder
 
 
@@ -37,12 +40,11 @@ __plugin_meta__ = PluginMetadata(
     extra={"author": "Alex Newton"},
 )
 
-scheduler = require("nonebot_plugin_apscheduler").scheduler
+require("nonebot_plugin_apscheduler")
+from nonebot_plugin_apscheduler import scheduler
 
 lol_today = on_command("lol", aliases={"LOL", "Lol"}, priority=5)
 driver = get_driver()
-driver.on_startup(LoLMatch.creat_table)
-driver.on_shutdown(disconnect_database)
 
 
 @lol_today.handle()
@@ -52,9 +54,7 @@ async def _(matcher: Matcher, event: GroupMessageEvent, args: Message = CommandA
         await lol_today.finish(await LoLMatch.show_week_matches())
     elif "查看订阅" in msg:
         try:
-            await lol_today.finish(
-                await LoLMatch.show_subbed_tournament(event.group_id)
-            )
+            await lol_today.finish(await LoLMatch.show_subbed_tournament(event.group_id))
         except ValueError:
             await lol_today.finish("检查输入联赛ID应为数字")
     elif "联赛详情" in msg:
@@ -68,14 +68,11 @@ async def _(matcher: Matcher, event: GroupMessageEvent, args: Message = CommandA
         except ValueError:
             await lol_today.finish("检查输入比赛ID应为数字")
     elif "取消订阅" in msg:
-        sub_id = msg.replace("取消订阅", '').strip()
-        await lol_today.finish(
-            await LoLMatch.cancel_tournament_group(int(sub_id), event.group_id))
+        sub_id = msg.replace("取消订阅", "").strip()
+        await lol_today.finish(await LoLMatch.cancel_tournament_group(int(sub_id), event.group_id))
     elif "订阅" in msg:
         sub_id = msg.replace("订阅", "").strip()
-        await lol_today.finish(
-            await LoLMatch.sub_tournament_group(int(sub_id), event.group_id)
-        )
+        await lol_today.finish(await LoLMatch.sub_tournament_group(int(sub_id), event.group_id))
     elif "联赛" in msg:
         await lol_today.finish(await LoLMatch.show_all_tournaments())
     else:
@@ -98,9 +95,7 @@ async def match_checker():
 
     msg_container = {}
     # 获取今日赛果
-    today_matches: Union[list, dict] = match_data[
-        datetime.datetime.now().strftime("%Y.%m.%d")
-    ]
+    today_matches: Union[list, dict] = match_data[datetime.datetime.now().strftime("%Y.%m.%d")]
     if isinstance(today_matches, list):
         pass  # 今日无比赛
     else:
@@ -109,10 +104,11 @@ async def match_checker():
             if int(tournamentID) not in sub_tournament:
                 continue  # 如果比赛不在订阅列表中不做处理
             match_result = (
-                    f"""<tr><th colspan="2" align="center">联赛ID: {tournamentID}&nbsp;&nbsp;&nbsp;&nbsp;{tournament_matches['tournamentinfo']['short_name']}</th></tr>"""
-                    + "".join(
-                f"""<tr><td>{match['match_id']}</td><td>{match['team_a_short_name']} {match['team_a_win']} <font color=red>VS</font> {match['team_b_win']} {match['team_b_short_name']}</td></tr>"""
-                for match in tournament_matches["list"])
+                f"""<tr><th colspan="2" align="center">联赛ID: {tournamentID}&nbsp;&nbsp;&nbsp;&nbsp;{tournament_matches['tournamentinfo']['short_name']}</th></tr>"""
+                + "".join(
+                    f"""<tr><td>{match['match_id']}</td><td>{match['team_a_short_name']} {match['team_a_win']} <font color=red>VS</font> {match['team_b_win']} {match['team_b_short_name']}</td></tr>"""
+                    for match in tournament_matches["list"]
+                )
             )
             for group_id in sub_dict[int(tournamentID)]:
                 tmp = msg_container.get(group_id, {"j": "", "m": ""})
@@ -126,14 +122,14 @@ async def match_checker():
         ava_keys.append(int(tour["tournamentID"]))
     for tournamentID in sub_dict.keys():
         if tournamentID not in ava_keys:
-            sub_dict.pop(tournamentID)
             await LoLMatch.del_tournament(tournamentID)
 
     # 处理明日赛程
     tomorrow = datetime.datetime.now() + datetime.timedelta(days=1)
     if tomorrow.strftime("%Y.%m.%d") not in match_data.keys():
         tomorrow_matches = (await LoLMatch.get_week_matches(str(tomorrow.date())))[
-            tomorrow.strftime("%Y.%m.%d")]
+            tomorrow.strftime("%Y.%m.%d")
+        ]
     else:
         tomorrow_matches = match_data[tomorrow.strftime("%Y.%m.%d")]
     if isinstance(tomorrow_matches, list):
@@ -144,10 +140,11 @@ async def match_checker():
             if int(tournamentID) not in sub_tournament:
                 continue  # 如果比赛不在订阅列表中不做处理
             match_result = (
-                    f"""<tr><th colspan="2" align="center">联赛ID: {tournamentID}&nbsp;&nbsp;&nbsp;&nbsp;{tournament_matches['tournamentinfo']['short_name']}</th></tr>"""
-                    + "".join(
-                f"""<tr><td>{match['start_time']}</td><td>{match['team_a_short_name']} <font color=red>VS</font> {match['team_b_short_name']}</td></tr>"""
-                for match in tournament_matches["list"])
+                f"""<tr><th colspan="2" align="center">联赛ID: {tournamentID}&nbsp;&nbsp;&nbsp;&nbsp;{tournament_matches['tournamentinfo']['short_name']}</th></tr>"""
+                + "".join(
+                    f"""<tr><td>{match['start_time']}</td><td>{match['team_a_short_name']} <font color=red>VS</font> {match['team_b_short_name']}</td></tr>"""
+                    for match in tournament_matches["list"]
+                )
             )
             for group_id in sub_dict[int(tournamentID)]:
                 tmp = msg_container.get(group_id, {"j": "", "m": ""})
@@ -159,8 +156,6 @@ async def match_checker():
         try:
             await bot.send_group_msg(group_id=group_id, message=MessageSegment.image(match_result))
         except NetworkError:
-            logger.warning(
-                f"{__plugin_meta__.name} 向群 {group_id} 发送 {match_result} 失败"
-            )
+            logger.warning(f"{__plugin_meta__.name} 向群 {group_id} 发送 {match_result} 失败")
         # 停1秒
-        await  asyncio.sleep(1)
+        await asyncio.sleep(1)
